@@ -1,78 +1,76 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.0">
 <context>
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <source>MX Codecs Installer</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="27"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="44"/>
         <source>Downloading codecs files</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="94"/>
         <source>Cancel any changes then quit</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="97"/>
         <location filename="../mainwindow.cpp" line="268"/>
         <source>Cancel</source>
-        <translation type="unfinished">キャンセル</translation>
+        <translation>キャンセル</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="104"/>
         <source>Alt+N</source>
-        <translation type="unfinished">Alt+N</translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="117"/>
-        <source>Apply any changes then quit</source>
-        <translation type="unfinished"></translation>
+        <source>Begin codec download and installation</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="120"/>
         <source>OK</source>
-        <translation type="unfinished">OK</translation>
+        <translation>OK</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="175"/>
         <source>About this application</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="178"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="185"/>
         <source>Alt+B</source>
-        <translation type="unfinished">Alt+B</translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="214"/>
         <source>Display help </source>
-        <translation type="unfinished">ヘルプの表示</translation>
+        <translation>ヘルプの表示</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="217"/>
         <source>Help</source>
-        <translation type="unfinished">ヘルプ</translation>
+        <translation>ヘルプ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="224"/>
         <source>Alt+H</source>
-        <translation type="unfinished">Alt+H</translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="105"/>
@@ -84,7 +82,7 @@
         <location filename="../mainwindow.cpp" line="153"/>
         <location filename="../mainwindow.cpp" line="161"/>
         <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;実行するコマンド...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="108"/>
@@ -97,7 +95,7 @@
         <location filename="../mainwindow.cpp" line="193"/>
         <location filename="../mainwindow.cpp" line="246"/>
         <source>Error</source>
-        <translation type="unfinished">エラー</translation>
+        <translation>エラー</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="109"/>
@@ -105,7 +103,7 @@
         <location filename="../mainwindow.cpp" line="141"/>
         <location filename="../mainwindow.cpp" line="158"/>
         <source>Cannot connect to the download site</source>
-        <translation type="unfinished"></translation>
+        <translation>ダウンロードサイトに接続できません</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="115"/>
@@ -113,103 +111,103 @@
         <location filename="../mainwindow.cpp" line="147"/>
         <location filename="../mainwindow.cpp" line="165"/>
         <source>Error downloading %1</source>
-        <translation type="unfinished"></translation>
+        <translation>ダウンロードエラー %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="170"/>
         <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;ダウンロードが完了しました。&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="189"/>
         <source>Installing downloaded files</source>
-        <translation type="unfinished"></translation>
+        <translation>ダウンロードファイルをインストール</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="194"/>
         <source>No downloaded *.debs files found.</source>
-        <translation type="unfinished"></translation>
+        <translation>ダウンロードした .deb ファイルが見つかりません。</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="207"/>
         <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;インストール中...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="220"/>
         <source>Error installing %1</source>
-        <translation type="unfinished"></translation>
+        <translation>インストールエラー %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="224"/>
         <source>Fix missing dependencies...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="226"/>
         <source>Error running %1 command</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="238"/>
         <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;インストール処理を完了しました&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="242"/>
         <source>Finished</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="243"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="247"/>
         <source>Process finished. Errors have occurred during the installation.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="261"/>
         <source>About MX Codecs</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="262"/>
         <source>MX Codecs</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="262"/>
         <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="264"/>
         <source>Simple codecs downloader for MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="265"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="266"/>
         <source>License</source>
-        <translation type="unfinished">ライセンス</translation>
+        <translation>ライセンス</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="267"/>
         <location filename="../mainwindow.cpp" line="277"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="285"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -217,12 +215,12 @@
     <message>
         <location filename="../main.cpp" line="53"/>
         <source>Unable to get exclusive lock</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../main.cpp" line="54"/>
         <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../main.cpp" line="67"/>
@@ -230,43 +228,4 @@
         <translation>このプログラムは root 権限で実行する必要があります。</translation>
     </message>
 </context>
-<context>
-    <name>mainwindow</name>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">キャンセル</translation>
-    </message>
-    <message>
-        <source>Alt+N</source>
-        <translation type="vanished">Alt+N</translation>
-    </message>
-    <message>
-        <source>OK</source>
-        <translation type="vanished">OK</translation>
-    </message>
-    <message>
-        <source>Alt+B</source>
-        <translation type="vanished">Alt+B</translation>
-    </message>
-    <message>
-        <source>Display help </source>
-        <translation type="vanished">ヘルプの表示</translation>
-    </message>
-    <message>
-        <source>Help</source>
-        <translation type="vanished">ヘルプ</translation>
-    </message>
-    <message>
-        <source>Alt+H</source>
-        <translation type="vanished">Alt+H</translation>
-    </message>
-    <message>
-        <source>Error</source>
-        <translation type="vanished">エラー</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">ライセンス</translation>
-    </message>
-</context>
-</TS>
+</TS>
\ No newline at end of file
